yakumo.cinder.v1

Package yakumo :: Package cinder :: Package v1 |
[hide private]
[frames] | no frames]

# Package v1

source code

Sub client class for Cinder API v1

Submodules | [hide private]
yakumo.cinder.v1.snapshot: Resource class and its manager for volumes on Block Storage V1 API yakumo.cinder.v1.volume: Resource class and its manager for volumes on Block Storage V1 API yakumo.cinder.v1.volume_type: Resource class and its manager for volumes on Block Storage V1 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.cinder.v1``'``